@@ -1,10 +1,11 @@
 #!/bin/false
-# ABSTRACT: MAC address functions and object
+# ABSTRACT: MAC hardware address functions and object (EUI48 and EUI64)
 
 use strict;
 use warnings;
+use v5.10;
 package NetAddr::MAC;
-$NetAddr::MAC::VERSION = '0.96';
+$NetAddr::MAC::VERSION = '0.97';
 
 use Carp qw( croak );
 use List::Util qw( first );
@@ -252,6 +253,33 @@ sub new {
 }
 
 
+sub random {
+
+    my ( $p, @q ) = @_;
+    my $c = ref($p) || $p;
+    my $self = bless {}, $c;
+
+    # clear the errstr, see also RT96045
+    $NetAddr::MAC::errstr = undef;
+
+    unless (@q) {
+        my $e = q|Please provide an oui prefix|;
+        croak "$e\n" if $NetAddr::MAC::die_on_error;
+        $NetAddr::MAC::errstr = $e;
+        return
+    }
+
+    die 'TODO';
+
+    # massage a single argument into a mac argument if needed
+    $self->_init( @q % 2 ? ( oui => shift @q, @q ) : @q )
+      or return;
+
+    return $self
+
+}
+
+
 sub original {
 
     my $self = shift;
@@ -952,11 +980,11 @@ __END__
 
 =head1 NAME
 
-NetAddr::MAC - MAC address functions and object
+NetAddr::MAC - MAC hardware address functions and object (EUI48 and EUI64)
 
 =head1 VERSION
 
-version 0.96
+version 0.97
 
 =head1 SYNOPSIS
 
@@ -1014,14 +1042,13 @@ version 0.96
 
 =head1 DESCRIPTION
 
-This module provides an interface to deal with Media Access Control (or MAC)
-addresses.  These are the addresses that uniquely identify a device on
-various layer 2 networks. Although the most common case is hardware addresses
-on Ethernet network cards, there are a variety of devices that use this
-system of addressing.
+This module provides an OO and functional interface to deal with Media Access
+Control (or MAC) addresses. These are the addresses that uniquely identify a
+device on various layer 2 networks. Although the most common case is hardware
+addresses on Ethernet network cards, there are a variety of devices that use
+this system of addressing.
 
-This module supports both Extended Unique Identifier 48 and 64,
-addresses and implements an OO and a functional interface.
+Both Extended Unique Identifier 48 and 64 addresses are supported.
 
 Some networks that use Extended Unique Identifier 48 (or MAC48) addresses include:
 
@@ -1043,19 +1070,20 @@ cisco errstr oui
 fx hsrp HSRPv2 vrrp autoconf
 pgsql unicast
 eui48 eui64
-4th
-
-=head1 NAME
-
-NetAddr::MAC - Handles hardware MAC Addresses (EUI48 and EUI64)
+4th vmware xen
 
 =head1 OO METHODS
 
-=head2 NetAddr::MAC->new( mac => $mac )
+=head2 new
+
+The B<new> method creates instances of this object. It can be called
+in any of the following ways.
+
+=head3 NetAddr::MAC->new( mac => $mac )
 
 Creates and returns a new NetAddr::MAC object.  The MAC value is required.
 
-=head2 NetAddr::MAC->new( mac => $mac, %options )
+=head3 NetAddr::MAC->new( mac => $mac, %options )
 
 As above, but %options may include any or none of the following
 
@@ -1091,14 +1119,36 @@ Priority defaults to 0 if not provided.
 
 =back
 
-=head2 NetAddr::MAC->new( $mac )
+=head3 NetAddr::MAC->new( $mac )
 
 Simplified creation method
 
-=head2 NetAddr::MAC->new( $mac, %options )
+=head3 NetAddr::MAC->new( $mac, %options )
 
 As above but with %options
 
+=head2 random
+
+As an alternative to L</new>, a "random" mac access based upon the provided
+B<oui> argument.
+
+Please consider the following information when selecting an OUI.
+
+If the first octal/digit/number is odd, then the MAC address L</is_multicast>
+
+OUI's used by virtualization software:
+
+Xen's prefix 00:16:3e
+VMware's prefix 00:50:56
+
+There are 4 sets of 'Locally Administered Address Ranges' that can be used
+without fear of conflict (from actual hardware):
+
+ x2-xx-xx-xx-xx-xx
+ x6-xx-xx-xx-xx-xx
+ xA-xx-xx-xx-xx-xx
+ xE-xx-xx-xx-xx-xx
+
 =head2 original
 
 Returns the original B<mac> string as used when creating the MAC object
@@ -1505,7 +1555,7 @@ Many young people like to use Github, so by all means send me pull requests at
 =head1 MOTIVATION
 
 There are lots of systems at my (then) place of work which handle MAC
-addresses. There was lots of code validating and normalising them all over
+addresses. There was lots of code validating and normalizing them all over
 the place - most of it was quirky and sloppy. So I set about creating a
 reusable module to add to our SOE install so that MAC address handling
 would become consistent, reliable, powerful and trivial.
@@ -1521,7 +1571,7 @@ dependencies and avoiding anything that doesn't work on perl 5.6
 
 I hope that the result is useful to others, the concept is to be able to create
 an object representing a MAC address based on a string that only very vaguely
-resembles a MAC address. From there, to be able to output normalised string
+resembles a MAC address. From there, to be able to output normalized string
 representations of the mac address in a variety of common formats.
 
 A templating function is deliberately omitted, as very niche outputs can easily
@@ -1536,7 +1586,7 @@ Dean Hamstead <dean@bytefoundry.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Dean Hamstad.
+This software is copyright (c) 2020 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
